==> adx-common-2.7.7.1-sources.jar: com/bxm/adx/common/openlog/listener/internal/DotAdxFilterEventListener.java <==
package com.bxm.adx.common.openlog.listener.internal;

import com.bxm.adx.common.AdxProperties;
import com.bxm.adx.common.OpenlogConstants;
import com.bxm.adx.common.market.Deal;
import com.bxm.adx.common.openlog.event.internal.AdxFilterEvent;
import com.bxm.adx.common.sell.builder.BuildAttribute;
import com.bxm.adx.common.sell.builder.BuildAttributeStringMacrosHandler;
import com.bxm.openlog.extension.client.OpenLogClient;
import com.bxm.warcar.integration.eventbus.EventListener;
import com.bxm.warcar.integration.eventbus.core.AllowConcurrentEvents;
import com.bxm.warcar.integration.eventbus.core.Subscribe;
import com.bxm.warcar.utils.JsonHelper;
import com.bxm.warcar.utils.UrlHelper;
import lombok.Data;
import lombok.experimental.Accessors;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @author fgf
 * @date 2023/3/27
 **/
@Slf4j
@Configuration
public class DotAdxFilterEventListener implements EventListener<AdxFilterEvent> {
    private OpenLogClient openLogClient;
    private final AdxProperties properties;
    private final BuildAttributeStringMacrosHandler macrosHandler;

    public DotAdxFilterEventListener(AdxProperties properties, BuildAttributeStringMacrosHandler macrosHandler) {
        this.properties = properties;
        this.macrosHandler = macrosHandler;
    }

    @Override
    @Subscribe
    @AllowConcurrentEvents
    public void consume(AdxFilterEvent event) {
        if (Math.abs(event.getSspRequest().getId().hashCode() % 100) >= properties.getDotSimplingPercent()) {
            return;
        }
        Map<Integer, Set<Deal>> trash = event.getTrashMap();
        List<FilterEntity> filterEntities = getFilterEntity(trash);
        MultiValueMap<String, String> customizeParams = new LinkedMultiValueMap<>();
        String value = UrlHelper.urlEncode(JsonHelper.convert(filterEntities));
        customizeParams.add(OpenlogConstants.MacrosCustomizeParams.ADX_FILTER, value);
        String url = properties.getOpenLog().create(true, OpenlogConstants.Mt.ADX_FILTER, customizeParams, OpenlogConstants.WITHOUT_MACROS_INNER);
        BuildAttribute attribute = new BuildAttribute(OpenlogConstants.Mt.ADX_FILTER)
                .setSspRequest(event.getSspRequest());
        url = macrosHandler.replaceAll(url, attribute);
        if (log.isDebugEnabled()) {
            log.debug("url: {}", url);
        }
        openLogClient.asyncRequest(url);
    }

    @Autowired
    public void setOpenLogClient(OpenLogClient openLogClient) {
        this.openLogClient = openLogClient;
    }

    public List<FilterEntity> getFilterEntity(Map<Integer, Set<Deal>> trash) {
        List<FilterEntity> filterEntities = new ArrayList<>();
        for (Map.Entry<Integer, Set<Deal>> entry : trash.entrySet()) {
            for (Deal deal : entry.getValue()) {
                filterEntities.add(
                        new FilterEntity()
                                .setType(entry.getKey())
                                .setDspid(deal.getDispatcher().getDspId())
                                .setDtagid(deal.getDispatcher().getDspPosid())
                                .setDappid(deal.getDispatcher().getDspAppid())
                );
            }
        }
        return filterEntities;
    }

    @Data
    @Accessors(chain = true)
    static class FilterEntity {
        private int type;
        private Long dspid;
        private String dtagid;
        private String dappid;
    }
}

==> adx-common-2.7.12-sources.jar: com/bxm/adx/common/openlog/listener/internal/DotAdxFilterEventListener.java <==
package com.bxm.adx.common.openlog.listener.internal;

import com.bxm.adx.common.AdxProperties;
import com.bxm.adx.common.OpenlogConstants;
import com.bxm.adx.common.market.Deal;
import com.bxm.adx.common.openlog.event.internal.AdxFilterEvent;
import com.bxm.adx.common.sell.builder.BuildAttribute;
import com.bxm.adx.common.sell.builder.BuildAttributeStringMacrosHandler;
import com.bxm.openlog.extension.client.OpenLogClient;
import com.bxm.warcar.integration.eventbus.EventListener;
import com.bxm.warcar.integration.eventbus.core.AllowConcurrentEvents;
import com.bxm.warcar.integration.eventbus.core.Subscribe;
import com.bxm.warcar.utils.JsonHelper;
import com.bxm.warcar.utils.UrlHelper;
import lombok.Data;
import lombok.experimental.Accessors;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import java.util.*;

/**
 * @author fgf
 * @date 2023/3/27
 **/
@Slf4j
@Configuration
public class DotAdxFilterEventListener implements EventListener<AdxFilterEvent> {
    private OpenLogClient openLogClient;
    private final AdxProperties properties;
    private final BuildAttributeStringMacrosHandler macrosHandler;

    public DotAdxFilterEventListener(AdxProperties properties, BuildAttributeStringMacrosHandler macrosHandler) {
        this.properties = properties;
        this.macrosHandler = macrosHandler;
    }

    @Override
    @Subscribe
    @AllowConcurrentEvents
    public void consume(AdxFilterEvent event) {
        if (Math.abs(event.getSspRequest().getId().hashCode() % 100) >= properties.getDotSimplingPercent()) {
            return;
        }
        Map<Integer, Set<Deal>> trash = event.getTrashMap();
        List<FilterEntity> filterEntities = getFilterEntity(trash);
        MultiValueMap<String, String> customizeParams = new LinkedMultiValueMap<>();
        String value = UrlHelper.urlEncode(JsonHelper.convert(filterEntities));
        customizeParams.add(OpenlogConstants.MacrosCustomizeParams.ADX_FILTER, value);
        String url = properties.getOpenLog().create(true, OpenlogConstants.Mt.ADX_FILTER, customizeParams, OpenlogConstants.WITHOUT_MACROS_INNER);
        BuildAttribute attribute = new BuildAttribute(OpenlogConstants.Mt.ADX_FILTER)
                .setSspRequest(event.getSspRequest());
        url = macrosHandler.replaceAll(url, attribute);
        if (log.isDebugEnabled()) {
            log.debug("url: {}", url);
        }
        openLogClient.asyncRequest(url);
    }

    @Autowired
    public void setOpenLogClient(OpenLogClient openLogClient) {
        this.openLogClient = openLogClient;
    }

    public List<FilterEntity> getFilterEntity(Map<Integer, Set<Deal>> trash) {
        List<FilterEntity> filterEntities = new ArrayList<>();
        for (Map.Entry<Integer, Set<Deal>> entry : trash.entrySet()) {
            for (Deal deal : entry.getValue()) {
                filterEntities.add(
                        new FilterEntity()
                                .setType(entry.getKey())
                                .setDspid(deal.getDispatcher().getDspId())
                                .setDtagid(deal.getDispatcher().getDspPosid())
                                .setDappid(deal.getDispatcher().getDspAppid())
                                .setErrResult(Objects.isNull(deal.getAdxErrEnum()) ? null : deal.getAdxErrEnum().getResult())
                );
            }
        }
        return filterEntities;
    }

    @Data
    @Accessors(chain = true)
    static class FilterEntity {
        private int type;
        private Long dspid;
        private String dtagid;
        private String dappid;
        /**
         * @see com.bxm.adx.facade.constant.enums.AdxErrEnum
         */
        private Integer errResult;
    }
}
